==> jc-1.4.0.tar.gz: soot/baf/internal/BDup1Inst.h <==
// public class soot.baf.internal.BDup1Inst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class dea91af903bdc6d2 soot_baf_internal_BDup1Inst
// @dep_class b9914bc9f2a73744 soot_baf_internal_BDupInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_BDupInst

#include "soot/baf/internal/BDupInst.h"

#ifndef _JC_soot_baf_internal_BDup1Inst_H_
#define _JC_soot_baf_internal_BDup1Inst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BDup1Inst$sub_refs	_jc_soot_baf_internal_BDup1Inst$sub_refs;
typedef struct _jc_soot_baf_internal_BDup1Inst$sub_nonrefs	_jc_soot_baf_internal_BDup1Inst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BDup1Inst$refs	_jc_soot_baf_internal_BDup1Inst$refs;
typedef struct _jc_soot_baf_internal_BDup1Inst$nonrefs	_jc_soot_baf_internal_BDup1Inst$nonrefs;
typedef struct _jc_soot_baf_internal_BDup1Inst$object	_jc_soot_baf_internal_BDup1Inst$object;

typedef const struct _jc_soot_baf_internal_BDup1Inst$vmethods	_jc_soot_baf_internal_BDup1Inst$vmethods;
typedef const struct _jc_soot_baf_internal_BDup1Inst$vtable	_jc_soot_baf_internal_BDup1Inst$vtable;
typedef const struct _jc_soot_baf_internal_BDup1Inst$vtype	_jc_soot_baf_internal_BDup1Inst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BDup1Inst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_soot_Type$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BDup1Inst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup1Inst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BDup1Inst$method$getOp1Type$5b5a95267a257907(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
extern struct _jc_object *_jc_soot_baf_internal_BDup1Inst$method$getOpTypes$b3c24cdbe2ebfd24(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
extern struct _jc_object *_jc_soot_baf_internal_BDup1Inst$method$getUnderTypes$0a8a26956d640ea7(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup1Inst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
extern void _jc_soot_baf_internal_BDup1Inst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getOp1Type$5b5a95267a257907;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getOpTypes$b3c24cdbe2ebfd24;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getUnderTypes$0a8a26956d640ea7;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_BDup1Inst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
	struct _jc_soot_Type$object	*(*getOp1Type$5b5a95267a257907)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
	struct _jc_object	*(*getOpTypes$b3c24cdbe2ebfd24)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
	struct _jc_object	*(*getUnderTypes$0a8a26956d640ea7)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_baf_internal_BDup1Inst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BDupInst$vmethods	soot_baf_internal_BDupInst;
	_jc_soot_baf_internal_BDup1Inst$vmethods	soot_baf_internal_BDup1Inst;
};

// Vtype
struct _jc_soot_baf_internal_BDup1Inst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BDup1Inst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup1Inst$sub_refs {
	struct _jc_soot_Type$object	*mOpType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BDup1Inst$refs {
    _jc_soot_baf_internal_BDup1Inst$sub_refs	soot_baf_internal_BDup1Inst;
    _jc_soot_baf_internal_BDupInst$sub_refs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup1Inst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BDup1Inst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BDupInst$sub_nonrefs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_BDup1Inst$sub_nonrefs	soot_baf_internal_BDup1Inst;
};

// Object instance structure
struct _jc_soot_baf_internal_BDup1Inst$object {
	_jc_soot_baf_internal_BDup1Inst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BDup1Inst$vtype	*vtype;
	_jc_soot_baf_internal_BDup1Inst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BDup1Inst$vtype _jc_soot_baf_internal_BDup1Inst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BDup1Inst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BDup1Inst$class_object;

#endif	/* _JC_soot_baf_internal_BDup1Inst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BDup1Inst.h <==
// public class soot.baf.internal.BDup1Inst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class dea91af903bdc6d2 soot_baf_internal_BDup1Inst
// @dep_class b9914bc9f2a73744 soot_baf_internal_BDupInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_BDupInst

#include "soot/baf/internal/BDupInst.h"

#ifndef _JC_soot_baf_internal_BDup1Inst_H_
#define _JC_soot_baf_internal_BDup1Inst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BDup1Inst$sub_refs	_jc_soot_baf_internal_BDup1Inst$sub_refs;
typedef struct _jc_soot_baf_internal_BDup1Inst$sub_nonrefs	_jc_soot_baf_internal_BDup1Inst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BDup1Inst$refs	_jc_soot_baf_internal_BDup1Inst$refs;
typedef struct _jc_soot_baf_internal_BDup1Inst$nonrefs	_jc_soot_baf_internal_BDup1Inst$nonrefs;
typedef struct _jc_soot_baf_internal_BDup1Inst$object	_jc_soot_baf_internal_BDup1Inst$object;

typedef const struct _jc_soot_baf_internal_BDup1Inst$vmethods	_jc_soot_baf_internal_BDup1Inst$vmethods;
typedef const struct _jc_soot_baf_internal_BDup1Inst$vtable	_jc_soot_baf_internal_BDup1Inst$vtable;
typedef const struct _jc_soot_baf_internal_BDup1Inst$vtype	_jc_soot_baf_internal_BDup1Inst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BDup1Inst$method$_init$39d637909e460d2e(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BDup1Inst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup1Inst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_BDup1Inst$method$getOp1Type$5b5a95267a257907(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_internal_BDup1Inst$method$getOpTypes$b3c24cdbe2ebfd24(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_baf_internal_BDup1Inst$method$getUnderTypes$0a8a26956d640ea7(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BDup1Inst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_BDup1Inst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getOp1Type$5b5a95267a257907;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getOpTypes$b3c24cdbe2ebfd24;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$getUnderTypes$0a8a26956d640ea7;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_BDup1Inst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_BDup1Inst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getOp1Type$5b5a95267a257907)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getOpTypes$b3c24cdbe2ebfd24)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUnderTypes$0a8a26956d640ea7)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_BDup1Inst$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BDup1Inst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BDupInst$vmethods	soot_baf_internal_BDupInst;
	_jc_soot_baf_internal_BDup1Inst$vmethods	soot_baf_internal_BDup1Inst;
};

// Vtype
struct _jc_soot_baf_internal_BDup1Inst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BDup1Inst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup1Inst$sub_refs {
	struct _jc_soot_Type$object	*mOpType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BDup1Inst$refs {
    _jc_soot_baf_internal_BDup1Inst$sub_refs	soot_baf_internal_BDup1Inst;
    _jc_soot_baf_internal_BDupInst$sub_refs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BDup1Inst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BDup1Inst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BDupInst$sub_nonrefs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_BDup1Inst$sub_nonrefs	soot_baf_internal_BDup1Inst;
};

// Object instance structure
struct _jc_soot_baf_internal_BDup1Inst$object {
	_jc_soot_baf_internal_BDup1Inst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BDup1Inst$vtype	*vtype;
	_jc_soot_baf_internal_BDup1Inst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BDup1Inst$vtype _jc_soot_baf_internal_BDup1Inst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BDup1Inst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BDup1Inst$class_object;

#endif	/* _JC_soot_baf_internal_BDup1Inst_H_ */
